@@ -5,9 +5,6 @@ import icemac.ab.importer.install
 import icemac.addressbook.addressbook
 import icemac.addressbook.testing
 import icemac.addressbook.utils
-import zope.component.globalregistry
-import zope.container.contained
-import zope.traversing.adapters
 
 
 class TestInstall(icemac.addressbook.testing.FunctionalTestCase):
@@ -26,7 +23,7 @@ class TestInstall(icemac.addressbook.testing.FunctionalTestCase):
 
     def setUp(self):
         super(TestInstall, self).setUp()
-        root = self.getRootFolder()
+        root = self.layer.getRootFolder()
         root['ab'] = self.ab = icemac.addressbook.utils.create_obj(
             icemac.addressbook.addressbook.AddressBook)
 
