@@ -62,9 +62,11 @@ class ImportFields(zc.sourcefactory.contextual.BasicContextualSourceFactory):
 
 import_fields = ImportFields()
 
+
 def split_keywords(keywords):
     return [x.strip() for x in keywords.split(',')]
 
+
 class IFieldValue(zope.interface.Interface):
     "Value for a specific field."
 
@@ -125,7 +127,7 @@ def bool_field(value, field):
         # We can't return None, as this means that the adapter can't adapt.
         return NONE_REPLACEMENT
     if not isinstance(value, unicode):
-        return value # produces an error in validation
+        return value  # produces an error in validation
     value = value.lower()
     if value in TRUE_VALUES:
         return True
@@ -230,6 +232,7 @@ def date_wrong_type(field, exc):
     value = exc.args[0]
     return _(u'${value} is no valid date.', mapping=dict(value=value))
 
+
 @zope.component.adapter(zope.schema.interfaces.IDatetime,
                         zope.schema.interfaces.WrongType)
 @zope.interface.implementer(IErrorMessage)
@@ -239,6 +242,7 @@ def datetime_wrong_type(field, exc):
              u'Must match to format string "${format}".',
              mapping=dict(value=value, format=DATETIME_FORMAT))
 
+
 @zope.component.adapter(zope.schema.interfaces.IInt,
                         zope.schema.interfaces.WrongType)
 @zope.interface.implementer(IErrorMessage)
@@ -366,15 +370,16 @@ class ImportObjectBuilder(object):
         """
         self.address_book = address_book
         self.entries_number = entries_number
-        self.import_entities = (
-            icemac.ab.importer.browser.wizard.base.get_import_entities())
+        entities = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities)
+        self.import_entities = entities.getMainEntities()
         for entity in self.import_entities:
             for index in xrange(self.entries_number):
                 key = "%s-%s" % (entity.name, index)
                 setattr(self, key, {})
         for field_desc, index in user_data.iteritems():
             if index is None:
-                continue # field was not selected for import
+                continue  # field was not selected for import
             prefix, field_name = field_desc.split('.')
             getattr(self, prefix)[field_name] = index
 
@@ -497,10 +502,10 @@ class MapFields(z3c.form.group.GroupForm,
         session = self.getContent()
         request = self.request
         self.groups = []
-        import_entities = (
-            icemac.ab.importer.browser.wizard.base.get_import_entities())
-        for entity in import_entities:
-            if entity.class_name  == 'icemac.addressbook.person.Person':
+        entities = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities)
+        for entity in entities.getMainEntities():
+            if entity.class_name == 'icemac.addressbook.person.Person':
                 entries_number = 1
                 main_prefix = ''
             else:
