@@ -3,9 +3,11 @@
 # See also LICENSE.txt
 
 from icemac.addressbook.i18n import MessageFactory as _
+import icemac.ab.importer.browser.wizard.base
 import icemac.addressbook.browser.table
 import icemac.addressbook.interfaces
 import icemac.addressbook.sources
+import icemac.truncatetext
 import xml.sax.saxutils
 import z3c.table.column
 import zope.i18n
@@ -16,13 +18,13 @@ import zope.security.proxy
 
 class ContainerColumn(z3c.table.column.GetAttrColumn):
     "Context is a container, search values in container items."
-    interface = None # search only objects providing this interface
-    container_interface = None # when value provides this interface, lookup
-                               # atribute on container
-    index = 0 # index in the list of found objects
-    attrName = None # attr to look up
-    attrInterface = None # interface of the attribute (needed to look up user
-                         # defined fields)
+    interface = None  # search only objects providing this interface
+    container_interface = None  # when value provides this interface, lookup
+                                # atribute on container
+    index = 0  # index in the list of found objects
+    attrName = None  # attr to look up
+    attrInterface = None  # interface of the attribute (needed to look up user
+                          # defined fields)
 
     def getObject(self, container):
         if (self.container_interface and
@@ -64,24 +66,19 @@ class CountryColumn(ContainerColumn):
 
 
 class TruncatedContentColumn(ContainerColumn):
+    """Truncate content to `lenght` characters."""
+    # This class does not use
+    # icemac.addressbook.browser.table.TruncatedContentColumn as base
+    # class, as the value is computed completely differently.
 
-    length = 20
-    ellipsis = u'…'
+    length = 20  # number of characters to display
+    ellipsis = u'…'  # ellipsis sign
 
     def getRawValue(self, obj):
         value = super(TruncatedContentColumn, self).getRawValue(obj)
         return icemac.truncatetext.truncate(value, self.length, self.ellipsis)
 
 
-class KeywordsColumn(z3c.table.column.GetAttrColumn):
-    """GetAttrColumn where attr is an iterable of keywords."""
-
-    def getValue(self, obj):
-        values = super(KeywordsColumn, self).getValue(obj)
-        return u', '.join(
-            icemac.addressbook.interfaces.ITitle(x) for x in values)
-
-
 def columnFactory(column):
     """Create a factory which returns the column, so the column can be used as
     an adapter without instanciating it."""
@@ -93,7 +90,8 @@ def columnFactory(column):
 ContainerColumnFactory = columnFactory(ContainerColumn)
 CountryColumnFactory = columnFactory(CountryColumn)
 TruncatedContentColumnFactory = columnFactory(TruncatedContentColumn)
-KeywordsColumnFactory = columnFactory(KeywordsColumn)
+KeywordsColumnFactory = columnFactory(
+    icemac.addressbook.browser.table.KeywordsColumn)
 
 
 class ReviewFields(zope.interface.Interface):
@@ -104,23 +102,21 @@ class ReviewFields(zope.interface.Interface):
 
 class ImportedTable(icemac.addressbook.browser.table.Table):
 
-    cssClassEven = u'table-even-row'
-    cssClassOdd = u'table-odd-row'
     sortOn = None
     no_rows_message = _(u'There was nothing to import in the import file.')
 
     def setUpColumns(self):
         cols = []
         weight = 0
-        import_entities = (
-            icemac.ab.importer.browser.wizard.base.get_import_entities())
-        for entity in import_entities:
+        entities = zope.component.getUtility(
+            icemac.addressbook.interfaces.IEntities)
+        for entity in entities.getMainEntities():
             if entity.class_name == 'icemac.addressbook.person.Person':
                 entries_number = 1
                 main_prefix = ''
             else:
-               entries_number = self.session['entries_number']
-               main_prefix = _(u'main')
+                entries_number = self.session['entries_number']
+                main_prefix = _(u'main')
             for index in xrange(entries_number):
                 first = True
                 for field_name, field in entity.getFieldsInOrder():
